//
//  configure.swift
//  SwiftyBot
//
//  The MIT License (MIT)
//
//  Copyright (c) 2016 - 2019 Fabrizio Brancati.
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included in all
//  copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
//  SOFTWARE.

import Assistant
import Messenger
import Telegram
import Vapor

/// Called before your application initializes.
public func configure(_ config: inout Config, _ env: inout Environment, _ services: inout Services) throws {
    /// Port to be used on production or development.
    let port = env == .production ? 1992 : 8080
    /// Creates a NIOServerConfig configuration for the app.
    let serverConfig = NIOServerConfig.default(hostname: "localhost", port: port)
    /// Register the server configuration.
    services.register(serverConfig)
    
    /// Register routes to the router.
    let router = EngineRouter.default()
    
    /// Add the Telegram routes.
    try Telegram.routes(router)
    /// Add the Facebook Messenger routes.
    try Messenger.routes(router)
    /// Add the Google Assistant routes.
    try Assistant.routes(router)
    /// Register all the routes.
    services.register(router, as: Router.self)

    /// Register middleware.
    /// Create _empty_ middleware config.
    var middlewares = MiddlewareConfig()
    /// Catches errors and converts to HTTP response.
    middlewares.use(ErrorMiddleware.self)
    /// Register middlewares to services.
    services.register(middlewares)
}
